#' @name PaulinoEx9.27
#' @title Sensibilidade Política de Trabalhadores
#' @description Estudo envolvendo sócios de um sindicato de
#'     trabalhadores gráficos. Tomaram-se três grupos definidos pelo
#'     nível de sensibilidade política. Os trabalhadores foram
#'     inquiridos sobre qual a posição de um dado partido face a uma
#'     determinada lei em dois momentos, no início e no fim do período
#'     de uma campanha eleitoral.
#' @format Um \code{data.frame} com 12 observações e 4 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{sensi}}{Nível de sensibilidade política (alto, médio ou
#'     baixo).}
#'
#' \item{\code{inicio}}{Instante em que foi aplicado o inquérito, início
#'     da campanha política (sim, não).}
#'
#' \item{\code{fim}}{Instante em que foi aplicado o inquérito, fim da
#'     campanha política (sim, não).}
#'
#'\item{\code{freq}}{Frequências observadas.}
#'
#' }
#' @keywords TC
#' @source PAULINO; SINGER (2006), Exemplo 9.27, pág. 342.
#' @examples
#' 
#' data(PaulinoEx9.27)
#' 
#' str(PaulinoEx9.27)
#' 
#' xt <- xtabs(freq ~ ., data = PaulinoEx9.27)
#' ftable(xt)
#'
#' library(lattice)
#'
#' barchart(xt,
#'          horizontal = FALSE,
#'          beside = FALSE,
#'          stack = FALSE,
#'          auto.key = list(space = "top", columns = 2, cex.title = 1,
#'                          rectangles = TRUE, points = FALSE,
#'                          title = "Fim da campanha eleitoral"),
#'          xlab = "Sensibilidade política",
#'          ylab = "Frequência")
#'
NULL